==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/ko-KR.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "B h\N{U+c2dc}",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "(E) B h:mm",
    EBhms => "(E) B h:mm:ss",
    EEEEd => "d\N{U+c77c} EEEE",
    EHm => "(E) HH:mm",
    EHms => "(E) HH:mm:ss",
    Ed => "d\N{U+c77c} (E)",
    Ehm => "(E) a h:mm",
    Ehms => "(E) a h:mm:ss",
    Gy => "G y\N{U+b144}",
    GyMMM => "G y\N{U+b144} MMM",
    GyMMMEEEEd => "G y\N{U+b144} MMM d\N{U+c77c} EEEE",
    GyMMMEd => "G y\N{U+b144} MMM d\N{U+c77c} (E)",
    GyMMMd => "G y\N{U+b144} MMM d\N{U+c77c}",
    H => "H\N{U+c2dc}",
    HHmmss => "HH:mm:ss",
    Hm => "HH:mm",
    Hms => "H\N{U+c2dc} m\N{U+bd84} s\N{U+cd08}",
    Hmsv => "H\N{U+c2dc} m\N{U+bd84} s\N{U+cd08} v",
    Hmv => "HH:mm v",
    M => "M\N{U+c6d4}",
    MEEEEd => "M. d. EEEE",
    MEd => "M. d. (E)",
    MMM => "LLL",
    MMMEEEEd => "MMM d\N{U+c77c} EEEE",
    MMMEd => "MMM d\N{U+c77c} (E)",
    "MMMMW-count-other" => "MMM W\N{U+bc88}\N{U+c9f8} \N{U+c8fc}",
    MMMMd => "MMMM d\N{U+c77c}",
    MMMd => "MMM d\N{U+c77c}",
    Md => "M. d.",
    d => "d\N{U+c77c}",
    h => "a h\N{U+c2dc}",
    hm => "a h:mm",
    hms => "a h:mm:ss",
    hmsv => "a h:mm:ss v",
    hmv => "a h:mm v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y\N{U+b144}",
    yM => "y. M.",
    yMEEEEd => "y. M. d. EEEE",
    yMEd => "y. M. d. (E)",
    yMM => "y. M.",
    yMMM => "y\N{U+b144} MMM",
    yMMMEEEEd => "y\N{U+b144} MMM d\N{U+c77c} EEEE",
    yMMMEd => "y\N{U+b144} MMM d\N{U+c77c} (E)",
    yMMMM => "y\N{U+b144} MMMM",
    yMMMd => "y\N{U+b144} MMM d\N{U+c77c}",
    yMd => "y. M. d.",
    yQQQ => "y\N{U+b144} QQQ",
    yQQQQ => "y\N{U+b144} QQQQ",
    "yw-count-other" => "Y\N{U+b144} w\N{U+bc88}\N{U+c9f8} \N{U+c8fc}",
  },
  code => "ko-KR",
  date_format_full => "y\N{U+b144} M\N{U+c6d4} d\N{U+c77c} EEEE",
  date_format_long => "y\N{U+b144} M\N{U+c6d4} d\N{U+c77c}",
  date_format_medium => "y. M. d.",
  date_format_short => "yy. M. d.",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+c6d4}",
    "\N{U+d654}",
    "\N{U+c218}",
    "\N{U+baa9}",
    "\N{U+ae08}",
    "\N{U+d1a0}",
    "\N{U+c77c}",
  ],
  day_format_narrow => [
    "\N{U+c6d4}",
    "\N{U+d654}",
    "\N{U+c218}",
    "\N{U+baa9}",
    "\N{U+ae08}",
    "\N{U+d1a0}",
    "\N{U+c77c}",
  ],
  day_format_wide => [
    "\N{U+c6d4}\N{U+c694}\N{U+c77c}",
    "\N{U+d654}\N{U+c694}\N{U+c77c}",
    "\N{U+c218}\N{U+c694}\N{U+c77c}",
    "\N{U+baa9}\N{U+c694}\N{U+c77c}",
    "\N{U+ae08}\N{U+c694}\N{U+c77c}",
    "\N{U+d1a0}\N{U+c694}\N{U+c77c}",
    "\N{U+c77c}\N{U+c694}\N{U+c77c}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+c6d4}",
    "\N{U+d654}",
    "\N{U+c218}",
    "\N{U+baa9}",
    "\N{U+ae08}",
    "\N{U+d1a0}",
    "\N{U+c77c}",
  ],
  day_stand_alone_narrow => [
    "\N{U+c6d4}",
    "\N{U+d654}",
    "\N{U+c218}",
    "\N{U+baa9}",
    "\N{U+ae08}",
    "\N{U+d1a0}",
    "\N{U+c77c}",
  ],
  day_stand_alone_wide => [
    "\N{U+c6d4}\N{U+c694}\N{U+c77c}",
    "\N{U+d654}\N{U+c694}\N{U+c77c}",
    "\N{U+c218}\N{U+c694}\N{U+c77c}",
    "\N{U+baa9}\N{U+c694}\N{U+c77c}",
    "\N{U+ae08}\N{U+c694}\N{U+c77c}",
    "\N{U+d1a0}\N{U+c694}\N{U+c77c}",
    "\N{U+c77c}\N{U+c694}\N{U+c77c}",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "\N{U+ae30}\N{U+c6d0}\N{U+c804}",
    "\N{U+c11c}\N{U+ae30}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%x (%a) %r",
  glibc_time_12_format => "%p %I\N{U+c2dc} %M\N{U+bd84} %S\N{U+cd08}",
  glibc_time_format => "%H\N{U+c2dc} %M\N{U+bd84} %S\N{U+cd08}",
  language => "Korean",
  month_format_abbreviated => [
    "1\N{U+c6d4}",
    "2\N{U+c6d4}",
    "3\N{U+c6d4}",
    "4\N{U+c6d4}",
    "5\N{U+c6d4}",
    "6\N{U+c6d4}",
    "7\N{U+c6d4}",
    "8\N{U+c6d4}",
    "9\N{U+c6d4}",
    "10\N{U+c6d4}",
    "11\N{U+c6d4}",
    "12\N{U+c6d4}",
  ],
  month_format_narrow => [
    "1\N{U+c6d4}",
    "2\N{U+c6d4}",
    "3\N{U+c6d4}",
    "4\N{U+c6d4}",
    "5\N{U+c6d4}",
    "6\N{U+c6d4}",
    "7\N{U+c6d4}",
    "8\N{U+c6d4}",
    "9\N{U+c6d4}",
    "10\N{U+c6d4}",
    "11\N{U+c6d4}",
    "12\N{U+c6d4}",
  ],
  month_format_wide => [
    "1\N{U+c6d4}",
    "2\N{U+c6d4}",
    "3\N{U+c6d4}",
    "4\N{U+c6d4}",
    "5\N{U+c6d4}",
    "6\N{U+c6d4}",
    "7\N{U+c6d4}",
    "8\N{U+c6d4}",
    "9\N{U+c6d4}",
    "10\N{U+c6d4}",
    "11\N{U+c6d4}",
    "12\N{U+c6d4}",
  ],
  month_stand_alone_abbreviated => [
    "1\N{U+c6d4}",
    "2\N{U+c6d4}",
    "3\N{U+c6d4}",
    "4\N{U+c6d4}",
    "5\N{U+c6d4}",
    "6\N{U+c6d4}",
    "7\N{U+c6d4}",
    "8\N{U+c6d4}",
    "9\N{U+c6d4}",
    "10\N{U+c6d4}",
    "11\N{U+c6d4}",
    "12\N{U+c6d4}",
  ],
  month_stand_alone_narrow => [
    "1\N{U+c6d4}",
    "2\N{U+c6d4}",
    "3\N{U+c6d4}",
    "4\N{U+c6d4}",
    "5\N{U+c6d4}",
    "6\N{U+c6d4}",
    "7\N{U+c6d4}",
    "8\N{U+c6d4}",
    "9\N{U+c6d4}",
    "10\N{U+c6d4}",
    "11\N{U+c6d4}",
    "12\N{U+c6d4}",
  ],
  month_stand_alone_wide => [
    "1\N{U+c6d4}",
    "2\N{U+c6d4}",
    "3\N{U+c6d4}",
    "4\N{U+c6d4}",
    "5\N{U+c6d4}",
    "6\N{U+c6d4}",
    "7\N{U+c6d4}",
    "8\N{U+c6d4}",
    "9\N{U+c6d4}",
    "10\N{U+c6d4}",
    "11\N{U+c6d4}",
    "12\N{U+c6d4}",
  ],
  name => "Korean South Korea",
  native_language => "\N{U+d55c}\N{U+ad6d}\N{U+c5b4}",
  native_name => "\N{U+d55c}\N{U+ad6d}\N{U+c5b4} \N{U+b300}\N{U+d55c}\N{U+bbfc}\N{U+ad6d}",
  native_script => undef,
  native_territory => "\N{U+b300}\N{U+d55c}\N{U+bbfc}\N{U+ad6d}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1\N{U+bd84}\N{U+ae30}",
    "2\N{U+bd84}\N{U+ae30}",
    "3\N{U+bd84}\N{U+ae30}",
    "4\N{U+bd84}\N{U+ae30}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+c81c} 1/4\N{U+bd84}\N{U+ae30}",
    "\N{U+c81c} 2/4\N{U+bd84}\N{U+ae30}",
    "\N{U+c81c} 3/4\N{U+bd84}\N{U+ae30}",
    "\N{U+c81c} 4/4\N{U+bd84}\N{U+ae30}",
  ],
  quarter_stand_alone_abbreviated => [
    "1\N{U+bd84}\N{U+ae30}",
    "2\N{U+bd84}\N{U+ae30}",
    "3\N{U+bd84}\N{U+ae30}",
    "4\N{U+bd84}\N{U+ae30}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+c81c} 1/4\N{U+bd84}\N{U+ae30}",
    "\N{U+c81c} 2/4\N{U+bd84}\N{U+ae30}",
    "\N{U+c81c} 3/4\N{U+bd84}\N{U+ae30}",
    "\N{U+c81c} 4/4\N{U+bd84}\N{U+ae30}",
  ],
  script => undef,
  territory => "South Korea",
  time_format_full => "a h\N{U+c2dc} m\N{U+bd84} s\N{U+cd08} zzzz",
  time_format_long => "a h\N{U+c2dc} m\N{U+bd84} s\N{U+cd08} z",
  time_format_medium => "a h:mm:ss",
  time_format_short => "a h:mm",
  variant => undef,
  version => 32,
}

==> DateTime-Locale-1.24.tar.gz: DateTime-Locale-1.24/share/ko-KR.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "B h\N{U+c2dc}",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "(E) B h:mm",
    EBhms => "(E) B h:mm:ss",
    EEEEd => "d\N{U+c77c} EEEE",
    EHm => "(E) HH:mm",
    EHms => "(E) HH:mm:ss",
    Ed => "d\N{U+c77c} (E)",
    Ehm => "(E) a h:mm",
    Ehms => "(E) a h:mm:ss",
    Gy => "G y\N{U+b144}",
    GyMMM => "G y\N{U+b144} MMM",
    GyMMMEEEEd => "G y\N{U+b144} MMM d\N{U+c77c} EEEE",
    GyMMMEd => "G y\N{U+b144} MMM d\N{U+c77c} (E)",
    GyMMMd => "G y\N{U+b144} MMM d\N{U+c77c}",
    H => "H\N{U+c2dc}",
    HHmmss => "HH:mm:ss",
    Hm => "HH:mm",
    Hms => "H\N{U+c2dc} m\N{U+bd84} s\N{U+cd08}",
    Hmsv => "H\N{U+c2dc} m\N{U+bd84} s\N{U+cd08} v",
    Hmv => "HH:mm v",
    M => "M\N{U+c6d4}",
    MEEEEd => "M. d. EEEE",
    MEd => "M. d. (E)",
    MMM => "LLL",
    MMMEEEEd => "MMM d\N{U+c77c} EEEE",
    MMMEd => "MMM d\N{U+c77c} (E)",
    "MMMMW-count-other" => "MMMM W\N{U+bc88}\N{U+c9f8} \N{U+c8fc}",
    MMMMd => "MMMM d\N{U+c77c}",
    MMMd => "MMM d\N{U+c77c}",
    Md => "M. d.",
    d => "d\N{U+c77c}",
    h => "a h\N{U+c2dc}",
    hm => "a h:mm",
    hms => "a h:mm:ss",
    hmsv => "a h:mm:ss v",
    hmv => "a h:mm v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y\N{U+b144}",
    yM => "y. M.",
    yMEEEEd => "y. M. d. EEEE",
    yMEd => "y. M. d. (E)",
    yMM => "y. M.",
    yMMM => "y\N{U+b144} MMM",
    yMMMEEEEd => "y\N{U+b144} MMM d\N{U+c77c} EEEE",
    yMMMEd => "y\N{U+b144} MMM d\N{U+c77c} (E)",
    yMMMM => "y\N{U+b144} MMMM",
    yMMMd => "y\N{U+b144} MMM d\N{U+c77c}",
    yMd => "y. M. d.",
    yQQQ => "y\N{U+b144} QQQ",
    yQQQQ => "y\N{U+b144} QQQQ",
    "yw-count-other" => "Y\N{U+b144} w\N{U+bc88}\N{U+c9f8} \N{U+c8fc}",
  },
  code => "ko-KR",
  date_format_full => "y\N{U+b144} M\N{U+c6d4} d\N{U+c77c} EEEE",
  date_format_long => "y\N{U+b144} M\N{U+c6d4} d\N{U+c77c}",
  date_format_medium => "y. M. d.",
  date_format_short => "yy. M. d.",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+c6d4}",
    "\N{U+d654}",
    "\N{U+c218}",
    "\N{U+baa9}",
    "\N{U+ae08}",
    "\N{U+d1a0}",
    "\N{U+c77c}",
  ],
  day_format_narrow => [
    "\N{U+c6d4}",
    "\N{U+d654}",
    "\N{U+c218}",
    "\N{U+baa9}",
    "\N{U+ae08}",
    "\N{U+d1a0}",
    "\N{U+c77c}",
  ],
  day_format_wide => [
    "\N{U+c6d4}\N{U+c694}\N{U+c77c}",
    "\N{U+d654}\N{U+c694}\N{U+c77c}",
    "\N{U+c218}\N{U+c694}\N{U+c77c}",
    "\N{U+baa9}\N{U+c694}\N{U+c77c}",
    "\N{U+ae08}\N{U+c694}\N{U+c77c}",
    "\N{U+d1a0}\N{U+c694}\N{U+c77c}",
    "\N{U+c77c}\N{U+c694}\N{U+c77c}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+c6d4}",
    "\N{U+d654}",
    "\N{U+c218}",
    "\N{U+baa9}",
    "\N{U+ae08}",
    "\N{U+d1a0}",
    "\N{U+c77c}",
  ],
  day_stand_alone_narrow => [
    "\N{U+c6d4}",
    "\N{U+d654}",
    "\N{U+c218}",
    "\N{U+baa9}",
    "\N{U+ae08}",
    "\N{U+d1a0}",
    "\N{U+c77c}",
  ],
  day_stand_alone_wide => [
    "\N{U+c6d4}\N{U+c694}\N{U+c77c}",
    "\N{U+d654}\N{U+c694}\N{U+c77c}",
    "\N{U+c218}\N{U+c694}\N{U+c77c}",
    "\N{U+baa9}\N{U+c694}\N{U+c77c}",
    "\N{U+ae08}\N{U+c694}\N{U+c77c}",
    "\N{U+d1a0}\N{U+c694}\N{U+c77c}",
    "\N{U+c77c}\N{U+c694}\N{U+c77c}",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "\N{U+ae30}\N{U+c6d0}\N{U+c804}",
    "\N{U+c11c}\N{U+ae30}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%Y. %m. %d. (%a) %H:%M:%S %Z",
  glibc_date_format => "%Y\N{U+b144} %m\N{U+c6d4} %d\N{U+c77c}",
  glibc_datetime_format => "%x (%a) %r",
  glibc_time_12_format => "%p %I\N{U+c2dc} %M\N{U+bd84} %S\N{U+cd08}",
  glibc_time_format => "%H\N{U+c2dc} %M\N{U+bd84} %S\N{U+cd08}",
  language => "Korean",
  month_format_abbreviated => [
    "1\N{U+c6d4}",
    "2\N{U+c6d4}",
    "3\N{U+c6d4}",
    "4\N{U+c6d4}",
    "5\N{U+c6d4}",
    "6\N{U+c6d4}",
    "7\N{U+c6d4}",
    "8\N{U+c6d4}",
    "9\N{U+c6d4}",
    "10\N{U+c6d4}",
    "11\N{U+c6d4}",
    "12\N{U+c6d4}",
  ],
  month_format_narrow => [
    "1\N{U+c6d4}",
    "2\N{U+c6d4}",
    "3\N{U+c6d4}",
    "4\N{U+c6d4}",
    "5\N{U+c6d4}",
    "6\N{U+c6d4}",
    "7\N{U+c6d4}",
    "8\N{U+c6d4}",
    "9\N{U+c6d4}",
    "10\N{U+c6d4}",
    "11\N{U+c6d4}",
    "12\N{U+c6d4}",
  ],
  month_format_wide => [
    "1\N{U+c6d4}",
    "2\N{U+c6d4}",
    "3\N{U+c6d4}",
    "4\N{U+c6d4}",
    "5\N{U+c6d4}",
    "6\N{U+c6d4}",
    "7\N{U+c6d4}",
    "8\N{U+c6d4}",
    "9\N{U+c6d4}",
    "10\N{U+c6d4}",
    "11\N{U+c6d4}",
    "12\N{U+c6d4}",
  ],
  month_stand_alone_abbreviated => [
    "1\N{U+c6d4}",
    "2\N{U+c6d4}",
    "3\N{U+c6d4}",
    "4\N{U+c6d4}",
    "5\N{U+c6d4}",
    "6\N{U+c6d4}",
    "7\N{U+c6d4}",
    "8\N{U+c6d4}",
    "9\N{U+c6d4}",
    "10\N{U+c6d4}",
    "11\N{U+c6d4}",
    "12\N{U+c6d4}",
  ],
  month_stand_alone_narrow => [
    "1\N{U+c6d4}",
    "2\N{U+c6d4}",
    "3\N{U+c6d4}",
    "4\N{U+c6d4}",
    "5\N{U+c6d4}",
    "6\N{U+c6d4}",
    "7\N{U+c6d4}",
    "8\N{U+c6d4}",
    "9\N{U+c6d4}",
    "10\N{U+c6d4}",
    "11\N{U+c6d4}",
    "12\N{U+c6d4}",
  ],
  month_stand_alone_wide => [
    "1\N{U+c6d4}",
    "2\N{U+c6d4}",
    "3\N{U+c6d4}",
    "4\N{U+c6d4}",
    "5\N{U+c6d4}",
    "6\N{U+c6d4}",
    "7\N{U+c6d4}",
    "8\N{U+c6d4}",
    "9\N{U+c6d4}",
    "10\N{U+c6d4}",
    "11\N{U+c6d4}",
    "12\N{U+c6d4}",
  ],
  name => "Korean South Korea",
  native_language => "\N{U+d55c}\N{U+ad6d}\N{U+c5b4}",
  native_name => "\N{U+d55c}\N{U+ad6d}\N{U+c5b4} \N{U+b300}\N{U+d55c}\N{U+bbfc}\N{U+ad6d}",
  native_script => undef,
  native_territory => "\N{U+b300}\N{U+d55c}\N{U+bbfc}\N{U+ad6d}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1\N{U+bd84}\N{U+ae30}",
    "2\N{U+bd84}\N{U+ae30}",
    "3\N{U+bd84}\N{U+ae30}",
    "4\N{U+bd84}\N{U+ae30}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+c81c} 1/4\N{U+bd84}\N{U+ae30}",
    "\N{U+c81c} 2/4\N{U+bd84}\N{U+ae30}",
    "\N{U+c81c} 3/4\N{U+bd84}\N{U+ae30}",
    "\N{U+c81c} 4/4\N{U+bd84}\N{U+ae30}",
  ],
  quarter_stand_alone_abbreviated => [
    "1\N{U+bd84}\N{U+ae30}",
    "2\N{U+bd84}\N{U+ae30}",
    "3\N{U+bd84}\N{U+ae30}",
    "4\N{U+bd84}\N{U+ae30}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+c81c} 1/4\N{U+bd84}\N{U+ae30}",
    "\N{U+c81c} 2/4\N{U+bd84}\N{U+ae30}",
    "\N{U+c81c} 3/4\N{U+bd84}\N{U+ae30}",
    "\N{U+c81c} 4/4\N{U+bd84}\N{U+ae30}",
  ],
  script => undef,
  territory => "South Korea",
  time_format_full => "a h\N{U+c2dc} m\N{U+bd84} s\N{U+cd08} zzzz",
  time_format_long => "a h\N{U+c2dc} m\N{U+bd84} s\N{U+cd08} z",
  time_format_medium => "a h:mm:ss",
  time_format_short => "a h:mm",
  variant => undef,
  version => 35,
}
